Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(183)

Unified Diff: content/public/browser/content_browser_client.h

Issue 9384014: Remove knowledge about SSLClientAuthHandler from chrome. Instead a callback is given to the embed... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: fix aura Created 8 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/public/browser/content_browser_client.h
===================================================================
--- content/public/browser/content_browser_client.h (revision 121323)
+++ content/public/browser/content_browser_client.h (working copy)
@@ -25,7 +25,6 @@
class RenderViewHost;
class ResourceDispatcherHost;
class SSLCertErrorHandler;
-class SSLClientAuthHandler;
class SkBitmap;
struct WebPreferences;
@@ -47,7 +46,9 @@
namespace net {
class CookieList;
class CookieOptions;
+class HttpNetworkSession;
class NetLog;
+class SSLCertRequestInfo;
class URLRequest;
class URLRequestContext;
class X509Certificate;
@@ -225,12 +226,14 @@
bool overridable,
const base::Callback<void(SSLCertErrorHandler*, bool)>& callback) = 0;
// Selects a SSL client certificate and returns it to the |handler|. If no
// certificate was selected NULL is returned to the |handler|.
virtual void SelectClientCertificate(
int render_process_id,
int render_view_id,
- SSLClientAuthHandler* handler) = 0;
+ const net::HttpNetworkSession* network_session,
+ net::SSLCertRequestInfo* cert_request_info,
+ const base::Callback<void(net::X509Certificate*)>& callback) = 0;
// Adds a downloaded client cert. The embedder should ensure that there's
// a private key for the cert, displays the cert to the user, and adds it upon
@@ -225,12 +226,14 @@
bool overridable,
const base::Callback<void(SSLCertErrorHandler*, bool)>& callback) = 0;
- // Selects a SSL client certificate and returns it to the |handler|. If no
- // certificate was selected NULL is returned to the |handler|.
+ // Selects a SSL client certificate and returns it to the |callback|. If no
+ // certificate was selected NULL is returned to the |callback|.
virtual void SelectClientCertificate(
int render_process_id,

Powered by Google App Engine
This is Rietveld 408576698